@@ -439,7 +439,7 @@ class water:
         min_k = 2
         score_index = 'calinsk'
         #unfix
-        max_k = 4
+        max_k = 5
         classifier = 'naivebayes'
         clustering_method = 'agglomerative'
         
@@ -500,7 +500,7 @@ class water:
             # pdb.set_trace()
             for item in lst:
                 if isinstance(item, list):
-                    uniques = DWutils.listify(item, uniques)
+                    uniques = listify(item, uniques)
                 else:
                     uniques.append(item)
             return uniques.copy()
@@ -538,7 +538,7 @@ class water:
         
         #create data bunch only with the bands used for clustering
         @staticmethod
-        def split_data_by_bands(data, selected_keys):
+        def split_data_by_bands(bands,data, selected_keys):
 
             bands_index = []
             bands_keys = list(sorted(bands.keys()))
@@ -549,10 +549,10 @@ class water:
         
     
         def find_best_k(self,data):
-            print('min_k :',self.min_k)
-            print('max_k :',self.max_k)
-            print('score_index :',self.score_index)
-            print(data)
+            # print('min_k :',self.min_k)
+            # print('max_k :',self.max_k)
+            # print('score_index :',self.score_index)
+            # print(data)
 
             if self.min_k == self.max_k:
                 print('Same number for minimum and maximum clusters: k = {}'.format(self.min_k))
@@ -564,10 +564,10 @@ class water:
             # else:
             #     print('Selection of best number of clusters using Calinski-Harabasz Index:')
 
-            if self.score_index == 'silhouette':
-                print('score_index : Silhouete')
-            else:
-                print('score_index : Calinski_harabaz')
+            # if self.score_index == 'silhouette':
+            #     print('score_index --> Silhouete')
+            # else:
+            #     print('score_index --> Calinski_harabaz')
 
             computed_metrics = []
             for num_k in range(self.min_k, self.max_k + 1):
@@ -578,14 +578,14 @@ class water:
 
                 if self.score_index == 'silhouette':
                     computed_metrics.append(metrics.silhouette_score(data, labels))
-                    print('k = {} index : {}'.format(num_k, computed_metrics[num_k - self.min_k]))
+                    # print('k = {} index : {}'.format(num_k, computed_metrics[num_k - self.min_k]))
 
                 else:
                     computed_metrics.append(calinski_harabasz_score(data, labels))
-                    print('k = {} index : {}'.format(num_k, computed_metrics[num_k - self.min_k]))
+                    # print('k = {} index : {}'.format(num_k, computed_metrics[num_k - self.min_k]))
 
             best_k = computed_metrics.index(max(computed_metrics)) + self.min_k
-            print("best_k :",best_k)
+            # print("best_k :",best_k)
 
             return best_k
         
@@ -626,7 +626,6 @@ class water:
         @staticmethod
         def detect_cluster(bands,clusters_params, param, logic, band1, band2=None):
             # get the bands available in the columns
-            print('1104')
             available_bands = sorted(bands.keys())
 
             param_list = []
@@ -656,14 +655,10 @@ class water:
             return clusters_params[idx_detected]
         
         def identify_water_cluster(self,detect_water_cluster,bands):
-            print("My.Data : detect_water_cluster: ",detect_water_cluster)
-            print("My.Data : bands : ",bands)
             if detect_water_cluster == 'maxmndwi':
                 if 'mndwi' not in bands.keys():
                     raise OSError('MNDWI band necessary for detecting water with maxmndwi option')
-                print('1103')
                 water_cluster = self.detect_cluster(bands,self.clusters_params,'value', 'max', 'mndwi')
-                print('My.data : self.clusters_params',self.clusters_params)
 
             # elif detect_water_cluster == 'maxmbwi':
             #     if 'mbwi' not in bands.keys():
@@ -694,7 +689,7 @@ class water:
             # train a NB classifier with the data and labels provided
             model = GaussianNB()
 
-            print('Applying clusters based naive bayes classifier')
+            # print('Applying clusters based --> naive bayes classifier')
             # print('Cross_val_score:{}'.format(cross_val_score(model, clusters_data, clusters_labels)))
 
             model.fit(clusters_data, clusters_labels)
@@ -725,7 +720,7 @@ class water:
             matrice_cluster[indices_array[0][clusters_labels == water_cluster['clusterid']],
                             indices_array[1][clusters_labels == water_cluster['clusterid']]] = 1
 
-            print('Assgnin 1 to cluster_id {}'.format(water_cluster['clusterid']))
+            # print('Assgnin 1 to cluster_id {}'.format(water_cluster['clusterid']))
 
             # loop through the remaining labels and apply value >= 3
             new_label = 2
@@ -737,7 +732,8 @@ class water:
 
                     new_label += 1
                 else:
-                    print('Skipping cluster_id {}'.format(label_i))
+                    pass
+                    # print('Skipping cluster_id {}'.format(label_i))
 
             return matrice_cluster
         ############################################ run_detect_water #############################################
@@ -746,51 +742,42 @@ class water:
         def waterdetect(self):
             ## wd.DWImageClustering
             # get the first band as reference of size
-            ref_band = list(bands.keys())[0]
-            ref_shape = bands[ref_band].shape
-            # print(ref_band,ref_shape)
+            ref_band = list(self.bands.keys())[0]
+            ref_shape = self.bands[ref_band].shape
 
             #check the invalid_mask
             invalid_mask = np.zeros(ref_shape,dtype=bool)
-            # print(invalid_mask)
             
             #check if the MNDWI index is necessary and if it exists
-            # # print('My.DataComponent : self.required_indices',self.required_indices)
-            # # print('My.DataComponent : bands',bands)
-            if 'mndwi' in self.required_indices and 'mndwi' not in bands:
-                mndwi,mndwi_mask = self.calc_normalized_difference(bands['Green'],bands['Mir2'],invalid_mask)
-                print(mndwi,mndwi_mask)
+            if 'mndwi' in self.required_indices and 'mndwi' not in self.bands:
+                mndwi,mndwi_mask = self.calc_normalized_difference(self.bands['Green'],self.bands['Mir2'],invalid_mask)
                 invalid_mask |= mndwi_mask
-                bands.update({'mndwi':mndwi})
-            # # print('My.DataComponent : bands :',bands)
+                self.bands.update({'mndwi':mndwi})
 
             #check if the NDWI index exist
-            if 'ndwi' in self.required_bands and 'ndwi' not in bands.keys():
-                ndwi,ndwi_mask = self.calc_normalized_difference(bands['Green'],bands['Nir'],invalid_mask)
+            if 'ndwi' in self.required_bands and 'ndwi' not in self.bands.keys():
+                ndwi,ndwi_mask = self.calc_normalized_difference(self.bands['Green'],self.bands['Nir'],invalid_mask)
                 invalid_mask |= ndwi_mask
-                bands.update({'ndwi':ndwi})
-            # print('My.DataComponent : bands :',bands)
+                self.bands.update({'ndwi':ndwi})
 
             #check if the MBWI index exist
-            if 'mbwi' in self.required_bands and 'mbwi' not in bands.keys():
-                print('x')
-                mbwi,mbwi_mask = self.calc_mbwi(bands,3,invalid_mask)
+            if 'mbwi' in self.required_bands and 'mbwi' not in self.bands.keys():
+                mbwi,mbwi_mask = self.calc_mbwi(self.bands,3,invalid_mask)
                 invalid_mask |= mbwi_mask
-                # bands.update({'mbwi':mbwi})
-            # print('My.DataComponent : bands :',bands)
 
             #check if the list contains the required bands
             for band in self.listify(self.bands_keys):
                 if band == 'otsu' or band == 'canny':
                     continue
-                if band not in bands.keys():
-                    raise OSError('Band {}, not available in the dictionary'.format(band))
-                if type(bands[band]) is not np.ndarray:
-                    raise OSError('Band {} is not a numpy array'.format(band))
-                if ref_shape != bands[band].shape:
-                    raise OSError('Bands {} and {} with different size in clustering core'.format(band, ref_band))
+                if band not in self.bands.keys():
+                    raise OSError('Band {}, not available in the dictionary'.format(self.band))
+                if type(self.bands[band]) is not np.ndarray:
+                    raise OSError('Band {} is not a numpy array'.format(self.band))
+                if ref_shape != self.bands[band].shape:
+                    raise OSError('Bands {} and {} with different size in clustering core'.format(self.band, ref_band))
                 else:
-                    print("it's ok")
+                    pass
+                    # print("band : ",band+"In require bands list")
 
             ## run_detect_water
             # print('My.DataComponent : self.bands_keys[0] :',self.bands_keys[0])
@@ -803,8 +790,7 @@ class water:
                 cluster_matrix = None
 
             #Transform the rasters in a matrix where each band is a column
-            data_as_columns = self.bands_to_columns(bands,invalid_mask)
-            # print('My.DataComponent : data_as_columns :',data_as_columns)
+            data_as_columns = self.bands_to_columns(self.bands,invalid_mask)
 
             # two line vectors indicating the indexes (line column) of valid pixels
             ind_data = np.where(~invalid_mask)   
@@ -814,46 +800,38 @@ class water:
                 train_data_as_columns=data_as_columns
             else:
                 train_data_as_columns,ts= self.get_train_test_split(data_as_columns,self.train_size,self.min_train_size,self.max_train_size)
-            # print('My.DataComponent : train_data_as_columns :',train_data_as_columns)
 
             #split1
-            split_train_data_as_columns = self.split_data_by_bands(train_data_as_columns,self.bands_keys)
+            split_train_data_as_columns = self.split_data_by_bands(self.bands,train_data_as_columns,self.bands_keys)
             #split2
-            split_data_as_columns = self.split_data_by_bands(data_as_columns,self.bands_keys)
-            # print('My.DataComponent : split_train_data_as_columns :',split_train_data_as_columns)
-            # print('My.DataComponent : split_data_as_columns :',split_data_as_columns)
+            split_data_as_columns = self.split_data_by_bands(self.bands,data_as_columns,self.bands_keys)
+
 
             #find best_k
             best_k = self.find_best_k(split_train_data_as_columns)
-            # print('My.DataComponent : best_k :',best_k)
 
             #apply the clusterization algorithm and return labels and train dataset
             train_clusters_labels = self.apply_cluster(split_train_data_as_columns,best_k)
-            # print('My.DataComponent : train_clusters_labels :',train_clusters_labels)
 
             #cals statistics for each cluster
             self.clusters_params = self.calc_clusters_params(train_data_as_columns,train_clusters_labels,best_k)
-            print('My.DataComponent : clusters_params :',self.clusters_params)
 
             #detect the water cluster
-            water_cluster = self.identify_water_cluster(self.detect_water_cluster,bands)
-            print('My.DataComponent : water_cluster :',water_cluster)
+            water_cluster = self.identify_water_cluster(self.detect_water_cluster,self.bands)
 
             if self.clustering_method != 'kmeans':
                 clusters_labels = self.supervised_classification(split_data_as_columns,split_train_data_as_columns,train_clusters_labels)
             else:
                 clusters_labels = train_clusters_labels
-            print('My.DataComponent : clusters_labels :',clusters_labels)
+            # print('My.DataComponent : clusters_labels :',clusters_labels)
             # after obtain the final labels,clip bands with superios limit
             for band,value in zip(self.clip_band,self.clip_sup_value):
-                print(band,value)
                 if value is not None:
                     if self.glint_mode and self.glint_processor is not None:
                         print('0')
                     else:
-                        print('1')
                         comp_array = value
-                    clusters_labels[(clusters_labels == water_cluster['clusterid']) & (bands[band][~invalid_mask]>comp_array)] = -1
+                    clusters_labels[(clusters_labels == water_cluster['clusterid']) & (self.bands[band][~invalid_mask]>comp_array)] = -1
             #after obtainting the final labels,clip bands with inferior limit
             for band,value in zip(self.clip_band,self.clip_inf_value):
                 if value is not None:
@@ -861,11 +839,11 @@ class water:
                         print('0')
                     else:
                         comp_array = value
-                    clusters_labels[(clusters_labels == water_cluster['clusterid']) & (bands[band][~invalid_mask]<comp_array)] = -1
+                    clusters_labels[(clusters_labels == water_cluster['clusterid']) & (self.bands[band][~invalid_mask]<comp_array)] = -1
             
             #create an cluster array based on the cluster result (water will be value1)
-            cluster_matrix = self.create_matrice_cluster(ind_data,bands,clusters_labels,water_cluster,best_k)
+            cluster_matrix = self.create_matrice_cluster(ind_data,self.bands,clusters_labels,water_cluster,best_k)
             water_mask = np.where(cluster_matrix == 1,1,np.where(invalid_mask == 1,255,0)).astype('int8')
             watermask0 = water_mask==0
             watermask1 = water_mask==1
-            return watermask1
\ No newline at end of file
+            return watermask1,water_mask
\ No newline at end of file
